==> Zephyrus-3.0.4.11414.tar.gz: Zephyrus-3.0.4.11414/Zephyrus/line/migrations/0001_initial.py <==
# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cms', '0016_auto_20160608_1535'),
    ]

    operations = [
        migrations.CreateModel(
            name='BeFriend',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(parent_link=True, related_name='line_befriend', auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin')),
                ('lineId', models.CharField(max_length=50, verbose_name='LINE ID')),
                ('count', models.BooleanField(default=False, verbose_name='Show count')),
                ('home', models.BooleanField(default=False, verbose_name='Show home')),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
        migrations.CreateModel(
            name='ShareLike',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(parent_link=True, related_name='line_sharelike', auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin')),
                ('url', models.URLField(default=None, null=True)),
                ('lineId', models.CharField(default=None, max_length=50, null=True, verbose_name='LINE ID')),
                ('share', models.BooleanField(default=True, verbose_name='Share')),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
        migrations.CreateModel(
            name='Transmission',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(parent_link=True, related_name='line_transmission', auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin')),
                ('type', models.CharField(default=b'a', max_length=1, verbose_name='Type', choices=[(b'a', 'Icon 1'), (b'b', 'Icon 2'), (b'c', 'Icon 3'), (b'd', 'Icon 4'), (b'e', 'Icon 5'), (b'f', 'Icon 6'), (b'g', 'Icon 7'), (b'h', 'Icon 8')])),
                ('url', models.URLField(default=None, null=True)),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
    ]

==> Zephyrus-4.1.9.13075.tar.gz: Zephyrus-4.1.9.13075/Zephyrus/line/migrations/0001_initial.py <==
# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cms', '0016_auto_20160608_1535'),
    ]

    operations = [
        migrations.CreateModel(
            name='BeFriend',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(parent_link=True, related_name='line_befriend', auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin', on_delete=models.CASCADE)),
                ('lineId', models.CharField(max_length=50, verbose_name='LINE ID')),
                ('count', models.BooleanField(default=False, verbose_name='Show count')),
                ('home', models.BooleanField(default=False, verbose_name='Show home')),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
        migrations.CreateModel(
            name='ShareLike',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(parent_link=True, related_name='line_sharelike', auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin', on_delete=models.CASCADE)),
                ('url', models.URLField(default=None, null=True)),
                ('lineId', models.CharField(default=None, max_length=50, null=True, verbose_name='LINE ID')),
                ('share', models.BooleanField(default=True, verbose_name='Share')),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
        migrations.CreateModel(
            name='Transmission',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(parent_link=True, related_name='line_transmission', auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin', on_delete=models.CASCADE)),
                ('type', models.CharField(default=b'a', max_length=1, verbose_name='Type', choices=[(b'a', 'Icon 1'), (b'b', 'Icon 2'), (b'c', 'Icon 3'), (b'd', 'Icon 4'), (b'e', 'Icon 5'), (b'f', 'Icon 6'), (b'g', 'Icon 7'), (b'h', 'Icon 8')])),
                ('url', models.URLField(default=None, null=True)),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
    ]
